#!/usr/bin/python

#########################################################################
# CrystalMonitor 6.1                                                    #
# Author: Mihael Simonic                                                #
# Licence: GPL                                                          #
#########################################################################

import karamba
import os
import os.path

def readFirstLine(fn):
	"""Tries to read and return the first non-empty line from file <fn>.
	
	If not possible, returns the None symbol."""

	if os.path.exists(fn):
		try:
		f = file(fn,"r")
		line=None
		while not line:
			line = f.readline().strip()
		f.close()
		return line
		except IOError, (errno, strerror):
		print "I/O error(%s): %s" % (errno,strerror)

def getDistro():
	"""Tries to get information about the installed distribution.
	
	Reads /etc/issue as last resort. Returns the None symbol if unsuccessful."""
	
	for fn in [ "/etc/slackware-version",
			"/etc/debian_version",
			"/etc/gentoo-release",
			"/etc/redhat-release",
			"/etc/fedora-release",
			"/etc/SuSE-release",
			"/etc/mandrakelinux-release",
			"/etc/kanotix-version",
			"/etc/issue" ]:
		distro=readFirstLine(fn)
		
		if distro:
		break
	return distro
def initWidget(widget):
	
	distro = getDistro()
	
	if not distro:
		distro = "Unknown"
		
	print "Distro is", distro

	distroText = karamba.getThemeText(widget,"distro")
	karamba.changeText(widget,distroText,distro)
	
	pass

def initWidget(widget):
	global search, answers, leftbuttonborders, rightbuttonborders, topbuttonborders, bottombuttonborders, no_configfile
	global odbcommand, odscommand, ofzcommand, obgcommand, oftcommand, otccommand, ofccommand
	odbcommand = odscommand = ofzcommand = obgcommand = oftcommand = ofccommand = otccommand = None
	
	# default values 
	if karamba.readConfigEntry(widget, "fredconfig") == None:
		karamba.writeConfigEntry(widget, "fontconfig", "KDEDefaultFont")
		karamba.writeConfigEntry(widget, "fontsizeconfig", "12")
		karamba.writeConfigEntry(widget, "bgredconfig", "255")
		karamba.writeConfigEntry(widget, "bggreenconfig", "255")
		karamba.writeConfigEntry(widget, "bgblueconfig", "255")
		karamba.writeConfigEntry(widget, "tredconfig", "0")
		karamba.writeConfigEntry(widget, "tgreenconfig", "0")
		karamba.writeConfigEntry(widget, "tblueconfig", "0")
		karamba.writeConfigEntry(widget, "fredconfig", "127")
		karamba.writeConfigEntry(widget, "fgreenconfig", "154")
		karamba.writeConfigEntry(widget, "fblueconfig", "199")
		karamba.writeConfigEntry(widget, "browserconfig", "default")
		karamba.writeConfigEntry(widget, "searchforconfig", "All")
		karamba.writeConfigEntry(widget, "clearbuttonconfig", "no")
	        karamba.writeConfigEntry(widget, "wikilinkconfig", "http://en.wikipedia.org/")
	fred = int(karamba.readConfigEntry(widget, "fredconfig"))
	fgreen = int(karamba.readConfigEntry(widget, "fgreenconfig"))
	fblue = int(karamba.readConfigEntry(widget, "fblueconfig"))
	tred = int(karamba.readConfigEntry(widget, "tredconfig"))
	tgreen = int(karamba.readConfigEntry(widget, "tgreenconfig"))
	tblue = int(karamba.readConfigEntry(widget, "tblueconfig"))
	bgred = int(karamba.readConfigEntry(widget, "bgredconfig"))
	bggreen = int(karamba.readConfigEntry(widget, "bggreenconfig"))
	bgblue = int(karamba.readConfigEntry(widget, "bgblueconfig"))
	fontsize = int(karamba.readConfigEntry(widget, "fontsizeconfig"))
	font = str(karamba.readConfigEntry(widget, "fontconfig"))
	browser = str(karamba.readConfigEntry(widget, "browserconfig"))
	searchfor = str(karamba.readConfigEntry(widget, "searchforconfig"))
	showclearbutton = str(karamba.readConfigEntry(widget, "clearbuttonconfig"))
	
	karamba.createBackgroundImage(widget, 0, 0, "themes/bgr_1.png")
	karamba.createInputBox(widget, 0, 0, 305, 308, "")
	
	
	for i in [answers, leftbuttonborders, rightbuttonborders, topbuttonborders, bottombuttonborders]:
		karamba.changeInputBoxFrameColor(widget, i, fred, fgreen, fblue)

	karamba.changeInputBoxFontColor(widget, answers, tred, tgreen, tblue)
	karamba.changeInputBoxBackgroundColor(widget, answers, bgred, bggreen, bgblue)
	karamba.changeInputBoxFontSize(widget, answers, fontsize)
	fontchange = karamba.changeInputBoxFont(widget, answers, font)
	
	search = karamba.createImage(widget, 116, 6, "images/button.png")
	karamba.attachClickArea(widget, search, "", "", "")
        #karamba.addMenuConfigOption(widget, "inputwikilink", "Input Wikipedia link")
	karamba.addMenuConfigOption(widget, "defaultbrowser", "Select theme")
	#karamba.addMenuConfigOption(widget, "inputboxframecolor", "Input Box Frame Color")
	#karamba.addMenuConfigOption(widget, "inputboxtextcolor", "Input Box Text Color")
	karamba.addMenuConfigOption(widget, "inputboxbgcolor", "Background Color")
	#karamba.addMenuConfigOption(widget, "inputboxfontsize", "Input Box Font Size")
	#karamba.addMenuConfigOption(widget, "inputboxfont", "Input Box Font")
	
	#for j in ["defaultbrowser", "inputboxframecolor", "inputboxtextcolor", "inputboxbgcolor", "inputboxfontsize", "inputboxfont"]:
	for j in ["defaultbrowser", "inputboxframecolor", "inputboxtextcolor", "inputboxbgcolor", "inputboxfontsize", "inputboxfont", "inputwikilink"]:
		karamba.setMenuConfigOption(widget, j, 0)	
	
def menuOptionChanged(widget, key, value):
	global browser, searchfor, cbutton, odbcommand, odscommand, ofccommand, otccommand, obgcommand, ofzcommand, oftcommand, owlcommand, answer
		
	bcommand = dscommand = fccomand = fzcomand = wlcommand = []
		

	if key == "inputboxfont":
		karamba.setMenuConfigOption(widget, "inputboxfont", 1)
		ftcomand = ['kdialog', '--title', 'Font Size', '--inputbox', 'Enter the font to be used in the input box:']
		oftcommand = karamba.executeInteractive(widget, ftcomand)
			
	if key == "inputboxfontsize":
		karamba.setMenuConfigOption(widget, "inputboxfontsize", 1)
		fzcomand = ['kdialog', '--title', 'Font Size', '--inputbox', 'Enter input box font size:']
		ofzcommand = karamba.executeInteractive(widget, fzcomand)
	
	if key == "inputboxbgcolor":
		karamba.setMenuConfigOption(widget, "inputboxbgcolor", 1)
		bgcomand = ['kdialog', '--title', 'Background Color', '--inputbox', 'Enter the color to be used for background in the input box using the following format: r=xxx g=xxx b=xxx']
		obgcommand = karamba.executeInteractive(widget, bgcomand)
	if key == "inputboxtextcolor":
		karamba.setMenuConfigOption(widget, "inputboxtextcolor", 1)
		tccomand = ['kdialog', '--title', 'Text Color', '--inputbox', 'Enter the color to be used for the text in the input box using the following format: r=xxx g=xxx b=xxx']
		otccommand = karamba.executeInteractive(widget, tccomand)
		
	if key == "inputboxframecolor":
		karamba.setMenuConfigOption(widget, "inputboxframecolor", 1)
		fccomand = ['kdialog', '--title', 'Frame Color', '--inputbox', 'Select the color to be used for the frame of the input box using the following format: r=xxx g=xxx b=xxx', fcolor]
		ofccommand = karamba.executeInteractive(widget, fccomand)
		
	if key == "defaultbrowser":
		#This is entry for theme!
		karamba.setMenuConfigOption(widget, "defaultbrowser", 1)
		browser = karamba.readConfigEntry(widget, "browserconfig")
		if str(browser) == "default":
			dbcommand = ['kdialog', '--radiolist', 'Select an iconset:', '1', 'Default', 'on', '2', 'Nuvola', 'off']
		elif str(browser) == "nuvola":
			dbcommand = ['kdialog', '--radiolist', 'Select an iconset:', '1', 'Default', 'off', '2', 'Nuvola', 'on']
		odbcommand = karamba.executeInteractive(widget, dbcommand)
		
#this is called everytime your widget is updated
#the update inverval is specified in the .theme file
def widgetUpdated(widget):
    pass

#This gets called everytime our widget is clicked.
#Notes:
#  widget = reference to our widget
#  x = x position (relative to our widget)
#  y = y position (relative to our widget)
#  botton = button clicked:
#                    1 = Left Mouse Button
#                    2 = Middle Mouse Button
#                    3 = Right Mouse Button, but this will never happen
#                        because the right mouse button brings up the
#                        Karamba menu.
#                    4,5 = Scroll wheel up and down
def widgetClicked(widget, x, y, button):
	pass
	
def meterClicked(widget, meter, button):
	global cbutton
		
	if meter == search:
		searching(widget)
		
	if meter == cbutton:
		karamba.changeInputBox(widget, answers, "")
		
		
#This gets called when a command you have executed with executeInteractive() outputs something
#to stdout.  This way you can get the output of for example kdialog without freezing up the widget
#waiting for kdialog to end.
#  widget = reference to your theme
#  pid = process number of the program outputting (use this if you execute more than out process)
#  output = the text the program outputted to stdout
def commandOutput(widget, pid, output):
	global oftcommand, ofzcommand, obgcommand, otccommand, ofccommand, odbcommand, odscommand, owlcommand, values, configfile, answers, leftbuttonborders, rightbuttonborders, topbuttonborders, bottombuttonborders
	
	output = output.replace("\n","")

	if pid == oftcommand:
		fontchange = karamba.changeInputBoxFont(widget, answers, str(output))
		karamba.setMenuConfigOption(widget, "inputboxfont", 0)
		karamba.writeConfigEntry(widget, "fontconfig", str(output))
			
	if pid == ofzcommand:
		if int(output) <= 0:
			ifcommand = ['kdialog', '--title', 'Size Error', '--error', 'Please enter a positive number']
			karamba.executeInteractive(widget, ifcommand)
			karamba.setMenuConfigOption(widget, "inputboxfontsize", 0)
			
		else:
			karamba.changeInputBoxFontSize(widget, answers, int(output))
			karamba.setMenuConfigOption(widget, "inputboxfontsize", 0)
			karamba.writeConfigEntry(widget, "fontsizeconfig", str(output))
		
	if pid == obgcommand:
		## including code from liquid weather theme: http://liquidweather.net/
		import re
		formattest = r'''(?ix)
		r=(?P<red>\d+)\sg=(?P<green>\d+)\sb=(?P<blue>\d+)
		'''
		match = re.search(formattest, output)
		if match == None:
			iccommand = ['kdialog', '--title',  'Formatting Error', '--error', 'Please enter color values in the correct format']
			karamba.executeInteractive(widget, iccommand)
			karamba.setMenuConfigOption(widget, "inputboxbgcolor", 0)
		elif (int(match.group('red')) > 255) or (int(match.group('green')) > 255) or (int(match.group('blue')) > 255):
			iccommand = ['kdialog', '--title', 'Value Error', '--error', 'r, g, b values may not be greater than 255']
			karamba.executeInteractive(widget, iccommand)
			karamba.setMenuConfigOption(widget, "inputboxbgcolor", 0)
		else:
			red = int(match.group('red'))
			green = int(match.group('green'))
			blue = int(match.group('blue'))
			karamba.changeInputBoxBackgroundColor(widget, answers, red, green, blue)
			karamba.setMenuConfigOption(widget, "inputboxbgcolor", 0)
			karamba.writeConfigEntry(widget, "bgredconfig", str(red))
			karamba.writeConfigEntry(widget, "bggreenconfig", str(green))
			karamba.writeConfigEntry(widget, "bgblueconfig", str(blue))
	
	if pid == otccommand:
		## including code from liquid weather theme: http://liquidweather.net/
		import re
		formattest = r'''(?ix)
		r=(?P<red>\d+)\sg=(?P<green>\d+)\sb=(?P<blue>\d+)
		'''
		match = re.search(formattest, output)
		if match == None:
			iccommand = ['kdialog', '--title',  'Formatting Error', '--error', 'Please enter color values in the correct format']
			karamba.executeInteractive(widget, iccommand)
			karamba.setMenuConfigOption(widget, "inputboxtextcolor", 0)
		elif (int(match.group('red')) > 255) or (int(match.group('green')) > 255) or (int(match.group('blue')) > 255):
			iccommand = ['kdialog', '--title', 'Value Error', '--error', 'r, g, b values may not be greater than 255']
			karamba.executeInteractive(widget, iccommand)
			karamba.setMenuConfigOption(widget, "inputboxtextcolor", 0)
		else:
			red = int(match.group('red'))
			green = int(match.group('green'))
			blue = int(match.group('blue'))
			karamba.changeInputBoxFontColor(widget, answers, red, green, blue)
			karamba.setMenuConfigOption(widget, "inputboxtextcolor", 0)
			karamba.writeConfigEntry(widget, "tredconfig", str(red))
			karamba.writeConfigEntry(widget, "tgreenconfig", str(green))
			karamba.writeConfigEntry(widget, "tblueconfig", str(blue))
	
	if pid == ofccommand:
		## including code from liquid weather theme: http://liquidweather.net/
		import re
		formattest = r'''(?ix)
		r=(?P<red>\d+)\sg=(?P<green>\d+)\sb=(?P<blue>\d+)
		'''
		match = re.search(formattest, output)
		if match == None:
			iccommand = ['kdialog', '--title',  'Formatting Error', '--error', 'Please enter color values in the correct format']
			karamba.executeInteractive(widget, iccommand)
			karamba.setMenuConfigOption(widget, "inputboxframecolor", 0)
		elif (int(match.group('red')) > 255) or (int(match.group('green')) > 255) or (int(match.group('blue')) > 255):
			iccommand = ['kdialog', '--title', 'Value Error', '--error', 'r, g, b values may not be greater than 255']
			karamba.executeInteractive(widget, iccommand)
			karamba.setMenuConfigOption(widget, "inputboxframecolor", 0)
		else:
			red = int(match.group('red'))
			green = int(match.group('green'))
			blue = int(match.group('blue'))
						
			for i in [answers, leftbuttonborders, rightbuttonborders, topbuttonborders, bottombuttonborders]:
				karamba.changeInputBoxFrameColor(widget, i, red, green, blue)
			
			karamba.setMenuConfigOption(widget, "inputboxframecolor", 0)
			karamba.writeConfigEntry(widget, "fredconfig", str(red))
			karamba.writeConfigEntry(widget, "fgreenconfig", str(green))
			karamba.writeConfigEntry(widget, "fblueconfig", str(blue))
	
	if pid == odbcommand:
		
		if output == "1":
			karamba.writeConfigEntry(widget, "browserconfig", "deflaut")
		elif output == "2":
			karamba.writeConfigEntry(widget, "browserconfig", "nuvola")
		karamba.setMenuConfigOption(widget, "defaultbrowser", 0)
		


#This gets called everytime our widget is clicked.
#Notes
#  widget = reference to our widget
#  x = x position (relative to our widget)
#  y = y position (relative to our widget)
#  botton = button being held:
#                    0 = No Mouse Button
#                    1 = Left Mouse Button
#                    2 = Middle Mouse Button
#                    3 = Right Mouse Button, but this will never happen
#                        because the right mouse button brings up the
#                        Karamba menu.
def widgetMouseMoved(widget, x, y, button):
    #Warning:  Don't do anything too intensive here
    #You don't want to run some complex piece of code everytime the mouse moves
    pass

def keyPressed(widget, meter, char):
	
		
# This will be printed when the widget loads.
print "Loaded CrystalMonitor python module!"

